## EMenus - a new way to make flexible menus

EMenus is a Python package that allows the creation of menus.

**Guide:** https://github.com/HUSKI3/EMenus/blob/master/GUIDE.md

**Things to come soon:**

 - Fully customizable menus
 - Coloured menus
 